% dfex.m - digital filter examples - generates graphs of Fig.12 of 
% "Lecture Notes on Elliptic Filter Design" by Sophocles J. Orfanidis, November 2006
% available from www.ece.rutgers.edu/~orfanidi/ece521
% email:   orfanidi@ece.rutgers.edu
% -----------------------------------------------------------------------------------

clear all;

fsamp = 20;
f = linspace(0,10,1001); 
w = 2*pi*f/fsamp;

% -------- LP -------------

fp = 4; fs = 4.5; 
Gp = 0.95; Gs = 0.05; 
Ap = -20*log10(Gp); As = -20*log10(Gs);    

for type=0:3,

[N,B,A] = dfdesign(fsamp,fp,fs,Ap,As,type); 

if type==3, N, B,A, end

H = fresp(B,A,w);

figure; plot(f,abs(H),'r');

xtick(0:1:10); ylim([0,1.1]); ytick(0:0.1:1); grid off;

line([0,fp],[1,1],'LineStyle',':'); 
line([fp,fp],[1,1.05],'LineStyle',':');
line([0,fp],[Gp,Gp]); line([fp,fp],[Gp,0]);
line([fs,10],[Gs,Gs]); line([fs,fs],[4*Gs,Gs]);

switch type
   case 0
      tit = strcat('LP,  Butterworth,  {\it N}=', sprintf('%d',N));
   case 1
      tit = strcat('LP,  Chebyshev-1,  {\it N}=', sprintf('%d',N));
   case 2
      tit = strcat('LP,  Chebyshev-2,  {\it N}=', sprintf('%d',N));
   case 3
      tit = strcat('LP,  Elliptic,  {\it N}=', sprintf('%d',N));
end

title(tit); xlabel('{\it f}');

fil = strcat('dlp',sprintf('%d',type),'.eps');
print('-depsc',fil); 

end

% -------- HP -------------

fp = 4.5; fs = 4; 
Gp = 0.95; Gs = 0.05; 
Ap = -20*log10(Gp); As = -20*log10(Gs);    

for type=0:3,

[N,B,A] = dfdesign(fsamp,fp,fs,Ap,As,type); 

if type==3, N, B,A, end

H = fresp(B,A,w);

figure; plot(f,abs(H),'r');

xtick(0:1:10); ylim([0,1.1]); ytick(0:0.1:1); grid off;

line([fp,10],[1,1],'LineStyle',':'); 
line([fp,fp],[1,1.05],'LineStyle',':');
line([fp,10],[Gp,Gp]); line([fp,fp],[Gp,0]);
line([0,fs],[Gs,Gs]); line([fs,fs],[4*Gs,Gs]);

switch type
   case 0
      tit = strcat('HP,  Butterworth,  {\it N}=', sprintf('%d',N));
   case 1
      tit = strcat('HP,  Chebyshev-1,  {\it N}=', sprintf('%d',N));
   case 2
      tit = strcat('HP,  Chebyshev-2,  {\it N}=', sprintf('%d',N));
   case 3
      tit = strcat('HP,  Elliptic,  {\it N}=', sprintf('%d',N));
end

title(tit); xlabel('{\it f}');;

fil = strcat('dhp',sprintf('%d',type),'.eps');
print('-depsc',fil); 

end

% -------- BP -------------

fpa=3; fpb=6; fsa=2.5; fsb=6.5;
Gp = 0.95; Gs = 0.05; 
Ap = -20*log10(Gp); As = -20*log10(Gs);    

for type=0:3,
   
[N,B,A] = dfdesign(fsamp, [fpa,fpb], [fsa,fsb], Ap, As, type); 

if type==3, N, B,A, end

H = fresp(B,A,w);

figure; plot(f,abs(H),'r');

xtick(0:1:10); ylim([0,1.1]); ytick(0:0.1:1); grid off;

line([fpa,fpb],[1,1],'LineStyle',':'); 
line([fpa,fpa],[1,1.05],'LineStyle',':'); line([fpb,fpb],[1,1.05],'LineStyle',':');
line([fpa,fpb],[Gp,Gp]); line([fpa,fpa],[Gp,0]); line([fpb,fpb],[Gp,0]);
line([0,fsa],[Gs,Gs]); line([fsa,fsa],[4*Gs,Gs]);
line([fsb,10],[Gs,Gs]); line([fsb,fsb],[4*Gs,Gs]);

switch type
   case 0
      tit = strcat('BP,  Butterworth,  {\it N}=', sprintf('%d',N));
   case 1
      tit = strcat('BP,  Chebyshev-1,  {\it N}=', sprintf('%d',N));
   case 2
      tit = strcat('BP,  Chebyshev-2,  {\it N}=', sprintf('%d',N));
   case 3
      tit = strcat('BP,  Elliptic,  {\it N}=', sprintf('%d',N));
end

title(tit); xlabel('{\it f}'); 

fil = strcat('dbp',sprintf('%d',type),'.eps');
print('-depsc',fil); 

end

% -------- BS -------------

fpa=2.5; fpb=6.5; fsa=3; fsb=6;
Gp = 0.95; Gs = 0.05; 
Ap = -20*log10(Gp); As = -20*log10(Gs);    

for type=0:3,
   
[N,B,A,Bh,Ah] = dfdesign(fsamp, [fpa,fpb], [fsa,fsb], Ap, As, type);  

if type==3, N, B,A, end

H = fresp(B,A,w);

figure; plot(f,abs(H),'r');

xtick(0:1:10); ylim([0,1.1]); ytick(0:0.1:1); grid off;

line([0,fpa],[1,1],'LineStyle',':'); line([fpb,10],[1,1],'LineStyle',':');
line([fpa,fpa],[1,1.05],'LineStyle',':'); line([fpb,fpb],[1,1.05],'LineStyle',':');
line([0,fpa],[Gp,Gp]); line([fpa,fpa],[Gp,0]); line([fpb,fpb],[Gp,0]); line([fpb,10],[Gp,Gp]);
line([fsa,fsb],[Gs,Gs]); line([fsa,fsa],[4*Gs,Gs]); line([fsb,fsb],[4*Gs,Gs]);

switch type
   case 0
      tit = strcat('BS,  Butterworth,  {\it N}=', sprintf('%d',N));
   case 1
      tit = strcat('BS,  Chebyshev-1,  {\it N}=', sprintf('%d',N));
   case 2
      tit = strcat('BS,  Chebyshev-2,  {\it N}=', sprintf('%d',N));
   case 3
      tit = strcat('BS,  Elliptic,  {\it N}=', sprintf('%d',N));
end

title(tit); xlabel('{\it f}');

fil = strcat('dbs',sprintf('%d',type),'.eps');
print('-depsc',fil); 

end

