% ellex1.m - elliptic filter design example given in Section 6 of
% "Lecture Notes on Elliptic Filter Design" by Sophocles J. Orfanidis, November 2006
% available from www.ece.rutgers.edu/~orfanidi/ece521
% email:   orfanidi@ece.rutgers.edu
% -----------------------------------------------------------------------------------

clear all;

fp = 4; fs = 4.5; Gp = 0.95; Gs = 0.05;   

Wp = 2*pi*fp; Ws = 2*pi*fs;

ep = sqrt(1/Gp^2 - 1); es = sqrt(1/Gs^2 - 1);

k = Wp/Ws;                                     
k1 = ep/es;                                    

[K,Kp] = ellipk(k); 
[K1,K1p] = ellipk(k1);

Nexact = (K1p/K1)/(Kp/K);  N = ceil(Nexact)

k = ellipdeg(N,k1);

fs_new = fp/k;

L=floor(N/2); r = mod(N,2); i = (1:L)'; 
u = (2*i-1)/N; zeta_i = cde(u,k);

za = Wp * j./(k*zeta_i);

v0 = -j*asne(j/ep, k1)/N;

pa = Wp * j*cde(u-j*v0, k);
pa0 = Wp * j*sne(j*v0, k);

B = [ones(L,1), -2*real(1./za), abs(1./za).^2];
A = [ones(L,1), -2*real(1./pa), abs(1./pa).^2];

if r==0,
  B = [Gp, 0, 0; B];
  A = [1, 0, 0; A];
else
  B = [1, 0, 0; B];
  A = [1, -real(1/pa0), 0; A];
end

f = linspace(0,10,2001); 

for n=1:length(f),
   s = j*2*pi*f(n);
   H(n) = prod((B(:,1) + B(:,2)*s + B(:,3)*s^2)./...
               (A(:,1) + A(:,2)*s + A(:,3)*s^2));
end

plot(f,abs(H),'r-');

xtick(0:1:10); ylim([0,1.1]); ytick(0:0.1:1); grid off;

title('Elliptic,  {\it N} = 5');
xlabel('{\it f}'); ylabel('|{\it H}({\it f})|');

line([0,fp],[1,1]); line([fp,fp],[1,1.05]);
line([0,fp],[Gp,Gp]); line([fp,fp],[Gp,0]);
line([fs_new,10],[Gs,Gs]); line([fs,fs],[4*Gs,Gs]);




   











