% ellex2.m  -  elliptic filter design example mentioned in Sect.7 of
% "Lecture Notes on Elliptic Filter Design" by Sophocles J. Orfanidis, November 2006
% available from www.ece.rutgers.edu/~orfanidi/ece521
% email:   orfanidi@ece.rutgers.edu
% -----------------------------------------------------------------------------------6

clear all;

fp = 4; fs = 4.5;
Wp = 2*pi*fp; Ws = 2*pi*fs;
Gp = 0.95; Gs = 0.05; 
Ap = -20*log10(Gp); As = -20*log10(Gs);    

type = 3;    % type = 0,1,2,3 for butter, cheby-1, cheby-2, elliptic

[N,B,A] = lpa(Wp,Ws,Ap,As,type);

f = linspace(0,10,1001); 
s = j*2*pi*f;             % s-domain

H = 1; 
for i=1:size(B,1),
   H = H .* (B(i,1) + B(i,2)*s + B(i,3)*s.^2) ./  (A(i,1) + A(i,2)*s + A(i,3)*s.^2);
end

plot(f,abs(H),'r');

xtick(0:1:10); ylim([0,1.1]); ytick(0:0.1:1); grid off;

line([0,fp],[1,1],'LineStyle',':'); 
line([fp,fp],[1,1.05],'LineStyle',':');
line([0,fp],[Gp,Gp]); line([fp,fp],[Gp,0]);
line([fs,10],[Gs,Gs]); line([fs,fs],[4*Gs,Gs]);



