% ellex3.m - elliptic filter design example given in Section 8 of
% "Lecture Notes on Elliptic Filter Design" by Sophocles J. Orfanidis, November 2006
% available from www.ece.rutgers.edu/~orfanidi/ece521
% email:   orfanidi@ece.rutgers.edu
% -----------------------------------------------------------------------------------

clear all;

fp1=3; fp2=6; fs1=2.5; fs2=6.5;
Wp1 = 2*pi*fp1; Wp2 = 2*pi*fp2; Ws1 = 2*pi*fs1; Ws2 = 2*pi*fs2;
Gp = 0.95; Gs = 0.05; 
Ap = -20*log10(Gp); As = -20*log10(Gs);    

Wp = Wp2-Wp1; W0 = sqrt(Wp1*Wp2);
W1 = Ws1 - W0^2/Ws1; W2 = Ws2 - W0^2/Ws2;
Ws = min(abs([W1,W2]));

type = 3;
[N,B,A] = lpa(Wp,Ws,Ap,As,type); 

f = linspace(0,10,1001); s = j*2*pi*f;
s = s + W0^2./s;                         % division by zero warning can be ignored

H = 1; 
for i=1:size(B,1),
   H = H .* (B(i,1) + B(i,2)*s + B(i,3)*s.^2) ./ (A(i,1) + A(i,2)*s + A(i,3)*s.^2);
end

plot(f,abs(H),'r');

xtick(0:1:10); ylim([0,1.1]); ytick(0:0.1:1); grid off;

line([fp1,fp2],[1,1],'LineStyle',':'); 
line([fp1,fp1],[1,1.05],'LineStyle',':'); line([fp2,fp2],[1,1.05],'LineStyle',':');
line([fp1,fp2],[Gp,Gp]); line([fp1,fp1],[Gp,0]); line([fp2,fp2],[Gp,0]);
line([0,fs1],[Gs,Gs]); line([fs1,fs1],[4*Gs,Gs]);
line([fs2,10],[Gs,Gs]); line([fs2,fs2],[4*Gs,Gs]);


